EXPORTS
	__ls__FR5RTestG5TTime @ 1 NONAME ; operator<<(RTest &, TTime)
	ChangeMessageTimeL__17CSchSendTestUtilslG5TTime @ 2 NONAME ; CSchSendTestUtils::ChangeMessageTimeL(long, TTime)
	CleanScheduleFolderL__17CSchSendTestUtils @ 3 NONAME ; CSchSendTestUtils::CleanScheduleFolderL(void)
	CompareRoundedTimes__C17CSchSendTestUtilsRC5TTimeT1 @ 4 NONAME ; CSchSendTestUtils::CompareRoundedTimes(TTime const &, TTime const &) const
	ConstructL__17CSchSendTestUtils @ 5 NONAME ; CSchSendTestUtils::ConstructL(void)
	CreateMessageLC__17CSchSendTestUtilsR9TMsvEntrylG5TTimei @ 6 NONAME ; CSchSendTestUtils::CreateMessageLC(TMsvEntry &, long, TTime, int)
	CreateServerMtmRegsL__17CSchSendTestUtils @ 7 NONAME ; CSchSendTestUtils::CreateServerMtmRegsL(void)
	DiffInMins__17CSchSendTestUtilsG5TTimeT1 @ 8 NONAME ; CSchSendTestUtils::DiffInMins(TTime, TTime)
	DiffInSecs__17CSchSendTestUtilsG5TTimeT1 @ 9 NONAME ; CSchSendTestUtils::DiffInSecs(TTime, TTime)
	DisplayAllSchedulesL__17CSchSendTestUtilsRiT1 @ 10 NONAME ; CSchSendTestUtils::DisplayAllSchedulesL(int &, int &)
	InstallMtmGroupsL__17CSchSendTestUtils @ 11 NONAME ; CSchSendTestUtils::InstallMtmGroupsL(void)
	NewL__17CSchSendTestTimeri @ 12 NONAME ; CSchSendTestTimer::NewL(int)
	NewL__19CScheduleTestActiveR17CSchSendTestUtilsi @ 13 NONAME ; CScheduleTestActive::NewL(CSchSendTestUtils &, int)
	Panic__17CSchSendTestUtilsi @ 14 NONAME ; CSchSendTestUtils::Panic(int)
	RoundDownToMinute__C17CSchSendTestUtilsRC5TTime @ 15 NONAME ; CSchSendTestUtils::RoundDownToMinute(TTime const &) const
	RoundUpToMinute__C17CSchSendTestUtilsRC5TTime @ 16 NONAME ; CSchSendTestUtils::RoundUpToMinute(TTime const &) const
	StartL__17CSchSendTestUtils @ 17 NONAME ; CSchSendTestUtils::StartL(void)
	StartsAt__FRC15TMsvOffPeakTimeRC5TTime @ 18 NONAME ; StartsAt(TMsvOffPeakTime const &, TTime const &)
	AssertL__17CSchSendTestUtilsi @ 19 NONAME ; CSchSendTestUtils::AssertL(int)
	"_._17CSchSendTestUtils" @ 20 NONAME ; CSchSendTestUtils::~CSchSendTestUtils(void)
	"_._19CScheduleTestActive" @ 21 NONAME ; CScheduleTestActive::~CScheduleTestActive(void)
	__17CSchSendTestUtilsR5RTest @ 22 NONAME ; CSchSendTestUtils::CSchSendTestUtils(RTest &)
	__eq__FRC15TMsvOffPeakTimeT0 @ 23 NONAME ; operator==(TMsvOffPeakTime const &, TMsvOffPeakTime const &)
	__eq__FRC19TMsvSendErrorActionT0 @ 24 NONAME ; operator==(TMsvSendErrorAction const &, TMsvSendErrorAction const &)
	__eq__FRC20CMsvScheduleSettingsT0 @ 25 NONAME ; operator==(CMsvScheduleSettings const &, CMsvScheduleSettings const &)
	__eq__FRC20CMsvSendErrorActionsT0 @ 26 NONAME ; operator==(CMsvSendErrorActions const &, CMsvSendErrorActions const &)
	TransferCommandSyncL__19CScheduleTestActive21TSchSendTestOperationRC18CMsvEntrySelectioni @ 27 NONAME ; CScheduleTestActive::TransferCommandSyncL(TSchSendTestOperation, CMsvEntrySelection const &, int)
	NewL__24CSchSendTestWaitForStateR17CSchSendTestUtils @ 28 NONAME ; CSchSendTestWaitForState::NewL(CSchSendTestUtils &)
	StartL__24CSchSendTestWaitForStateRC18CMsvEntrySelection @ 29 NONAME ; CSchSendTestWaitForState::StartL(CMsvEntrySelection const &)
	StartL__24CSchSendTestWaitForStateRC18CMsvEntrySelectionG27TTimeIntervalMicroSeconds32 @ 30 NONAME ; CSchSendTestWaitForState::StartL(CMsvEntrySelection const &, TTimeIntervalMicroSeconds32)
	"_._24CSchSendTestWaitForState" @ 31 NONAME ; CSchSendTestWaitForState::~CSchSendTestWaitForState(void)
	Reset__24CSchSendTestWaitForState @ 32 NONAME ; CSchSendTestWaitForState::Reset(void)
	TransferCommandSyncL__19CScheduleTestActive21TSchSendTestOperationRC18CMsvEntrySelectionRC6TDesC8i @ 33 NONAME ; CScheduleTestActive::TransferCommandSyncL(TSchSendTestOperation, CMsvEntrySelection const &, TDesC8 const &, int)
	__eq__FRC19TMsvSchedulePackageT0 @ 34 NONAME ; operator==(TMsvSchedulePackage const &, TMsvSchedulePackage const &)

